# WorkCategoryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**work_category** | [**WorkCategoryResponseEnum**](WorkCategoryResponseEnum.md) |  | 
**work_category_string** | **str** |  | 
**duration** | [**DurationCalculationResponse**](DurationCalculationResponse.md) |  | 
**validity_period_end_date** | **datetime** |  | 
**is_early_start** | **bool** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

